@@ -75,7 +75,8 @@ class ResourceAttributesMixin(object):
         return Resource(
             base_url=url_join(self._meta.base_url, item),
             format=self._meta.format,
-            authentication=self._meta.authentication
+            authentication=self._meta.authentication,
+            append_slash=self._meta.append_slash,
         )
 
 
@@ -94,6 +95,7 @@ class Resource(ResourceAttributesMixin, MetaMixin, object):
         authentication = None
         base_url = None
         format = "json"
+        append_slash = True
 
     def __init__(self, *args, **kwargs):
         super(Resource, self).__init__(*args, **kwargs)
@@ -103,7 +105,7 @@ class Resource(ResourceAttributesMixin, MetaMixin, object):
         if self._meta.authentication is not None:
             self._http.add_credentials(**self._meta.authentication)
 
-    def __call__(self, id=None, format=None, url_overide=None):
+    def __call__(self, id=None, format=None, url_override=None):
         """
         Returns a new instance of self modified by one or more of the available
         parameters. These allows us to do things like override format for a
@@ -112,7 +114,7 @@ class Resource(ResourceAttributesMixin, MetaMixin, object):
         """
 
         # Short Circuit out if the call is empty
-        if id is None and format is None and url_overide is None:
+        if id is None and format is None and url_override is None:
             return self
 
         kwargs = dict([x for x in self._meta.__dict__.items() if not x[0].startswith("_")])
@@ -123,11 +125,11 @@ class Resource(ResourceAttributesMixin, MetaMixin, object):
         if format is not None:
             kwargs["format"] = format
 
-        if url_overide is not None:
+        if url_override is not None:
             # @@@ This is hacky and we should probably figure out a better way
             #    of handling the case when a POST/PUT doesn't return an object
             #    but a Location to an object that we need to GET.
-            kwargs["base_url"] = url_overide
+            kwargs["base_url"] = url_override
         
         return self.__class__(**kwargs)
 
@@ -138,6 +140,9 @@ class Resource(ResourceAttributesMixin, MetaMixin, object):
         s = self.get_serializer()
         url = self._meta.base_url
 
+        if self._meta.append_slash and not url.endswith("/"):
+            url = url + "/"
+
         if "body" in kwargs:
             body = kwargs.pop("body")
         else:
@@ -208,10 +213,10 @@ class Resource(ResourceAttributesMixin, MetaMixin, object):
 class API(ResourceAttributesMixin, MetaMixin, object):
 
     class Meta:
-        format = "json"
         authentication = None
-
         base_url = None
+        format = "json"
+        append_slash = True
 
     def __init__(self, base_url=None, **kwargs):
         if base_url is not None:
